@@ -14,6 +14,8 @@ function _aws_cdk_aws_redshiftserverless_CfnNamespaceProps(p) {
 }
 function _aws_cdk_aws_redshiftserverless_CfnNamespace(p) {
 }
+function _aws_cdk_aws_redshiftserverless_CfnNamespace_NamespaceProperty(p) {
+}
 function _aws_cdk_aws_redshiftserverless_CfnWorkgroupProps(p) {
     if (p == null)
         return;
@@ -32,6 +34,14 @@ function _aws_cdk_aws_redshiftserverless_CfnWorkgroup(p) {
 }
 function _aws_cdk_aws_redshiftserverless_CfnWorkgroup_ConfigParameterProperty(p) {
 }
+function _aws_cdk_aws_redshiftserverless_CfnWorkgroup_EndpointProperty(p) {
+}
+function _aws_cdk_aws_redshiftserverless_CfnWorkgroup_NetworkInterfaceProperty(p) {
+}
+function _aws_cdk_aws_redshiftserverless_CfnWorkgroup_VpcEndpointProperty(p) {
+}
+function _aws_cdk_aws_redshiftserverless_CfnWorkgroup_WorkgroupProperty(p) {
+}
 function print(name, deprecationMessage) {
     const deprecated = process.env.JSII_DEPRECATED;
     const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
@@ -68,4 +78,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_redshiftserverless_CfnNamespaceProps, _aws_cdk_aws_redshiftserverless_CfnNamespace, _aws_cdk_aws_redshiftserverless_CfnWorkgroupProps, _aws_cdk_aws_redshiftserverless_CfnWorkgroup, _aws_cdk_aws_redshiftserverless_CfnWorkgroup_ConfigParameterProperty };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_redshiftserverless_CfnNamespaceProps, _aws_cdk_aws_redshiftserverless_CfnNamespace, _aws_cdk_aws_redshiftserverless_CfnNamespace_NamespaceProperty, _aws_cdk_aws_redshiftserverless_CfnWorkgroupProps, _aws_cdk_aws_redshiftserverless_CfnWorkgroup, _aws_cdk_aws_redshiftserverless_CfnWorkgroup_ConfigParameterProperty, _aws_cdk_aws_redshiftserverless_CfnWorkgroup_EndpointProperty, _aws_cdk_aws_redshiftserverless_CfnWorkgroup_NetworkInterfaceProperty, _aws_cdk_aws_redshiftserverless_CfnWorkgroup_VpcEndpointProperty, _aws_cdk_aws_redshiftserverless_CfnWorkgroup_WorkgroupProperty };
